@@ -124,7 +124,7 @@ def test_add_local_named_range():
     wb = Workbook()
     new_sheet = wb.create_sheet()
     named_range = NamedRange('test_nr', [(new_sheet, 'A1')])
-    named_range.local_only = True
+    named_range.scope = new_sheet
     wb.add_named_range(named_range)
     dest_filename = osp.join(TMPDIR, 'local_named_range_book.xlsx')
     wb.save(dest_filename)
@@ -146,3 +146,18 @@ def test_write_regular_date():
 
     eq_(test_sheet.cell("A1").value, today)
         
+@with_setup(setup = make_tmpdir, teardown = clean_tmpdir)
+def test_write_regular_float():
+
+    float_value = 1.0 / 3.0
+    book = Workbook()
+    sheet = book.get_active_sheet()
+    sheet.cell("A1").value = float_value
+    dest_filename = osp.join(TMPDIR, 'float_read_write_issue.xlsx')
+    book.save(dest_filename)
+
+    test_book = load_workbook(dest_filename)
+    test_sheet = test_book.get_active_sheet()
+
+    eq_(test_sheet.cell("A1").value, float_value)
+
