@@ -38,6 +38,7 @@ from openpyxl.shared.exc import SheetTitleException, \
 from openpyxl.shared.password_hasher import hash_password
 from openpyxl.style import Style, DEFAULTS as DEFAULTS_STYLE
 from openpyxl.drawing import Drawing
+from openpyxl.namedrange import NamedRangeContainingValue
 
 _DEFAULTS_STYLE_HASH = hash(DEFAULTS_STYLE)
 
@@ -225,6 +226,8 @@ class Worksheet(object):
         self.show_summary_right = True
         self.default_row_dimension = RowDimension()
         self.default_column_dimension = ColumnDimension()
+        self._auto_filter = None
+        self._freeze_panes = None
 
     def __repr__(self):
         return u'<Worksheet "%s">' % self.title
@@ -269,6 +272,38 @@ class Worksheet(object):
                      'Get or set the title of the worksheet. '
                      'Limited to 31 characters, no special characters.')
 
+    def _set_auto_filter(self, range):
+        # Normalize range to a str or None
+        if not range:
+            range = None
+        elif isinstance(range, str):
+            range = range.upper()
+        else: # Assume a range
+            range = range[0][0].address + ':' + range[-1][-1].address
+        self._auto_filter = range
+
+    def _get_auto_filter(self):
+        return self._auto_filter
+
+    auto_filter = property(_get_auto_filter, _set_auto_filter, doc =
+                           'get or set auto filtering on columns')
+    def _set_freeze_panes(self, topLeftCell):
+        if not topLeftCell:
+            topLeftCell = None
+        elif isinstance(topLeftCell, str):
+            topLeftCell = topLeftCell.upper()
+        else: # Assume a cell
+            topLeftCell = topLeftCell.address
+        if topLeftCell == 'A1':
+            topLeftCell = None
+        self._freeze_panes = topLeftCell
+
+    def _get_freeze_panes(self):
+        return self._freeze_panes
+
+    freeze_panes = property(_get_freeze_panes,_set_freeze_panes, doc =
+                           "Get or set frozen panes")
+
     def cell(self, coordinate = None, row = None, column = None):
         """Returns a cell object based on the given coordinates.
 
@@ -395,6 +430,9 @@ class Worksheet(object):
             if named_range is None:
                 msg = '%s is not a valid range name' % range_string
                 raise NamedRangeException(msg)
+            if isinstance(named_range, NamedRangeContainingValue):
+                msg = '%s refers to a value, not a range' % range_string
+                raise NamedRangeException(msg)
 
             result = []
             for destination in named_range.destinations:
